@@ -1,5 +1,7 @@
 import PySimpleGUI as sg
-from NetLogoDOE.src.gui.custom_components import title, configuration_parameter_text, configuration_value_text, configuration_horizontal_line
+
+from NetLogoDOE.src.gui.custom_components import title, configuration_parameter_text, configuration_value_text, \
+    configuration_horizontal_line
 
 
 class StandardConfigTableScreen:
